@@ -2,10 +2,11 @@ import pytz
 
 from django.core.exceptions import ValidationError
 from django.db import models
-from django.utils.encoding import smart_unicode
+from django.utils import six
+from django.utils.encoding import smart_text
 
 
-class TimeZoneField(models.Field):
+class TimeZoneFieldBase(models.Field):
     """
     Provides database store for pytz timezone objects.
 
@@ -32,8 +33,6 @@ class TimeZoneField(models.Field):
 
     description = "A pytz timezone object"
 
-    __metaclass__ = models.SubfieldBase
-
     CHOICES = [(pytz.timezone(tz), tz) for tz in pytz.all_timezones]
     MAX_LENGTH = 63
 
@@ -43,7 +42,7 @@ class TimeZoneField(models.Field):
             'choices': TimeZoneField.CHOICES,
         }
         defaults.update(kwargs)
-        super(TimeZoneField, self).__init__(**defaults)
+        super(TimeZoneFieldBase, self).__init__(**defaults)
 
     def get_internal_type(self):
         return 'CharField'
@@ -59,19 +58,23 @@ class TimeZoneField(models.Field):
     def _get_python_and_db_repr(self, value):
         "Returns a tuple of (python representation, db representation)"
         if value is None or value == '':
-            return (None, '')
+            return (None, None)
         if value is pytz.UTC or isinstance(value, pytz.tzinfo.BaseTzInfo):
-            return (value, smart_unicode(value))
-        if isinstance(value, basestring):
+            return (value, smart_text(value))
+        if isinstance(value, six.string_types):
             try:
-                tz_value = pytz.timezone(value)
+                return (pytz.timezone(value), value)
             except pytz.UnknownTimeZoneError:
                 pass
-            else:
-                return (tz_value, value)
         raise ValidationError("Invalid timezone '%s'" % value)
 
 
+# http://packages.python.org/six/#six.with_metaclass
+class TimeZoneField(six.with_metaclass(models.SubfieldBase,
+                                       TimeZoneFieldBase)):
+    pass
+
+
 # South support
 try:
     from south.modelsinspector import add_introspection_rules
@@ -84,7 +87,7 @@ else:
             [],                 # Positional arguments (not used)
             {                   # Keyword argument
                 'max_length': [
-                    'max_length', { 'default': TimeZoneField.MAX_LENGTH }
+                    'max_length', {'default': TimeZoneField.MAX_LENGTH},
                 ],
             },
         )],
